package com.ruoyi.web.controller.ems;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.ems.domain.EmsSubsystem;
import com.ruoyi.ems.service.IEmsSubsystemService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 能源子系统Controller
 *
 * @author ruoyi
 * @date 2024-08-16
 */
@RestController
@RequestMapping("/ems/subsystem")
@Api(value = "EmsSubsystemController", description = "能源子系统管理")
public class EmsSubsystemController extends BaseController
{
    @Autowired
    private IEmsSubsystemService emsSubsystemService;

    /**
     * 查询能源子系统列表
     */
    @GetMapping("/list")
    public TableDataInfo list(EmsSubsystem emsSubsystem)
    {
        startPage();
        List<EmsSubsystem> list = emsSubsystemService.selectEmsSubsystemList(emsSubsystem);
        return getDataTable(list);
    }

    /**
     * 查询能源子系统列表
     */
    @GetMapping("/listAll")
    public AjaxResult listAll(EmsSubsystem emsSubsystem)
    {
        return success( emsSubsystemService.selectEmsSubsystemList(emsSubsystem));
    }


    /**
     * 导出能源子系统列表
     */
    @PreAuthorize("@ss.hasPermi('adapter:subsystem:export')")
    @Log(title = "能源子系统", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EmsSubsystem emsSubsystem)
    {
        List<EmsSubsystem> list = emsSubsystemService.selectEmsSubsystemList(emsSubsystem);
        ExcelUtil<EmsSubsystem> util = new ExcelUtil<EmsSubsystem>(EmsSubsystem.class);
        util.exportExcel(response, list, "能源子系统数据");
    }

    /**
     * 获取能源子系统详细信息
     */
    @PreAuthorize("@ss.hasPermi('adapter:subsystem:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(emsSubsystemService.selectEmsSubsystemById(id));
    }

    /**
     * 新增能源子系统
     */
    @PreAuthorize("@ss.hasPermi('adapter:subsystem:add')")
    @Log(title = "能源子系统", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmsSubsystem emsSubsystem)
    {
        return toAjax(emsSubsystemService.insertEmsSubsystem(emsSubsystem));
    }

    /**
     * 修改能源子系统
     */
    @PreAuthorize("@ss.hasPermi('adapter:subsystem:edit')")
    @Log(title = "能源子系统", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmsSubsystem emsSubsystem)
    {
        return toAjax(emsSubsystemService.updateEmsSubsystem(emsSubsystem));
    }

    /**
     * 删除能源子系统
     */
    @PreAuthorize("@ss.hasPermi('adapter:subsystem:remove')")
    @Log(title = "能源子系统", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(emsSubsystemService.deleteEmsSubsystemByIds(ids));
    }
}
